==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/AssigningPolarMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningPolarStyleEventArgsBaseDescriptionMetadata } from "./AssigningPolarStyleEventArgsBaseDescriptionMetadata";
import { AssigningPolarMarkerStyleEventArgsDescription } from "./AssigningPolarMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningPolarMarkerStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningPolarMarkerStyleEventArgsDescriptionMetadata, _super);
    function AssigningPolarMarkerStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a == null) {
            AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningPolarMarkerStyleEventArgsDescriptionMetadata.c(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
        }
        if (a.g(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningPolarStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningPolarMarkerStyleEventArgsDescriptionMetadata.b(a);
        a.u("AssigningPolarMarkerStyleEventArgs", function () { return new AssigningPolarMarkerStyleEventArgsDescription(); });
        a.t("AssigningPolarMarkerStyleEventArgs", AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningPolarMarkerStyleEventArgsDescriptionMetadata, 'AssigningPolarMarkerStyleEventArgsDescriptionMetadata');
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningPolarMarkerStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningPolarMarkerStyleEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/AssigningPolarMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningPolarStyleEventArgsBaseDescriptionMetadata } from "./AssigningPolarStyleEventArgsBaseDescriptionMetadata";
import { AssigningPolarMarkerStyleEventArgsDescription } from "./AssigningPolarMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningPolarMarkerStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningPolarMarkerStyleEventArgsDescriptionMetadata, _super);
    function AssigningPolarMarkerStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a == null) {
            AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningPolarMarkerStyleEventArgsDescriptionMetadata.c(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
        }
        if (a.j(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningPolarStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningPolarMarkerStyleEventArgsDescriptionMetadata.b(a);
        a.aa("AssigningPolarMarkerStyleEventArgs", function () { return new AssigningPolarMarkerStyleEventArgsDescription(); });
        a.z("AssigningPolarMarkerStyleEventArgs", AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningPolarMarkerStyleEventArgsDescriptionMetadata, 'AssigningPolarMarkerStyleEventArgsDescriptionMetadata');
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningPolarMarkerStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningPolarMarkerStyleEventArgsDescriptionMetadata };
